@@ -5,7 +5,7 @@ import time
 import urllib
 from datetime import datetime
 
-LINKEDIN_API = "https://3hz1hdpnlf.execute-api.eu-west-1.amazonaws.com/prod/"
+LINKEDIN_API = "https://3hz1hdpnlf.execute-api.eu-west-1.amazonaws.com/prod"
 RELEASE_MESSAGE = (
     "Feature not release yet."
     "Please create or comment issue on Jupyter Naas Github: "
@@ -36,13 +36,14 @@ class LinkedIn(InDriver, OutDriver):
         # Check if requests is successful
         try:
             res.raise_for_status()
+            res_json = res.json()
+            return (
+                res_json.get("data", {})
+                .get("entityUrn")
+                .replace("urn:li:fs_profile:", "")
+            )
         except requests.HTTPError as e:
             return e
-        else:
-            res_json = res.json()
-        return (
-            res_json.get("data", {}).get("entityUrn").replace("urn:li:fs_profile:", "")
-        )
 
     def get_birthdate(self, bd):
         if bd is None:
@@ -164,13 +165,11 @@ class LinkedIn(InDriver, OutDriver):
             adress = pf.get("geoLocationName")
             lk_headline = pf.get("headline")
             lk_industry = pf.get("industryName")
-
         # Get network info
         nw = network.get("data")
         lk_followers = None
         if nw is not None:
             lk_followers = nw.get("followersCount")
-
         # Get contact info
         ct = contact.get("data")
         lk_phone = None
@@ -191,7 +190,6 @@ class LinkedIn(InDriver, OutDriver):
                 for rows in lk_twiters:
                     lk_twiter = rows["name"]
                     break
-
         # Profile dict
         lk_profile = {
             "FIRSTNAME": firstname,
@@ -212,7 +210,6 @@ class LinkedIn(InDriver, OutDriver):
 
         if output == "json":
             return lk_profile
-
         if output == "dataframe":
             df = pd.DataFrame.from_records([lk_profile])
             return df
@@ -263,7 +260,6 @@ class LinkedIn(InDriver, OutDriver):
                         "PROFILE_PUBLIC_ID": publicidentifier,
                     }
                     lk_profile.append(tmp_dict)
-
             if lk_type == "com.linkedin.voyager.messaging.Conversation":
                 # Init variable
                 profile_id = None
@@ -281,7 +277,6 @@ class LinkedIn(InDriver, OutDriver):
                     lastactivityat = datetime.fromtimestamp(lastactivityat / 1000.0)
                 if lastreadat is not None:
                     lastreadat = datetime.fromtimestamp(lastreadat / 1000.0)
-
                 # Create conversation dict
                 profile_id = str(profile_id).rsplit(",")[-1].rsplit(")")[0]
                 if profile_id != "UNKNOWN":
@@ -293,7 +288,6 @@ class LinkedIn(InDriver, OutDriver):
                         "LAST_READ_AT": lastreadat,
                     }
                     lk_conversation.append(tmp_dict)
-
             if lk_type == "com.linkedin.voyager.messaging.Event":
                 # Init variable
                 message_id = None
@@ -309,7 +303,6 @@ class LinkedIn(InDriver, OutDriver):
                         if key == "attributedBody":
                             message_text = m.get("eventContent").get(key).get("text")
                             break
-
                 # Create event dict
                 tmp_dict = {}
                 tmp_dict = {
@@ -318,7 +311,6 @@ class LinkedIn(InDriver, OutDriver):
                     "MESSAGE_TYPE": message_type,
                 }
                 lk_event.append(tmp_dict)
-
         # Convert dict to dataframe
         df_profile = pd.DataFrame.from_records(lk_profile)
         df_conversation = pd.DataFrame.from_records(lk_conversation)
@@ -397,7 +389,6 @@ class LinkedIn(InDriver, OutDriver):
                     datepost = (
                         p.get("actor").get("subDescription").get("accessibilityText")
                     )
-
         # Data
         data = {
             "URL": url,
@@ -429,11 +420,9 @@ class LinkedIn(InDriver, OutDriver):
         self.print_deprecated("post.get_likes()")
         if post_link:
             thread_urn = urllib.parse.quote(LinkedIn.get_post_urn(post_link), safe="")
-
         if not thread_urn:
             print("Error, specify a 'post_link' or a 'thread_urn'")
             return None
-
         user = {
             "URN_ID": [],
             "PUBLIC_IDENTIFIER": [],
@@ -644,18 +633,18 @@ class Profile(LinkedIn):
         return pd.DataFrame([result])
 
     def get_posts_stats(self, profile_url=None, profile_urn=None):
-        params = {}
-        if profile_url:
-            params["profile_url"] = profile_url
-        if profile_urn:
-            params["profile_urn"] = profile_urn
-        req_url = f"{LINKEDIN_API}/profile/getPostsStats?{urllib.parse.urlencode(params, safe='(),')}"
+        res_json = {}
+        if profile_urn is None:
+            profile_urn = LinkedIn.get_profile_urn(self, profile_url)
+            if profile_urn is None:
+                return "Please enter a valid profile_url or profile_urn"
+        req_url = f"{LINKEDIN_API}/profile/getPostsStats?profile_urn={profile_urn}"
         headers = {"Content-Type": "application/json"}
         res = requests.post(req_url, json=self.cookies, headers=headers)
         try:
             res.raise_for_status()
-        except requests.HTTPError:
-            res_json = {}
+        except requests.HTTPError as e:
+            return e
         else:
             res_json = res.json()
         df = pd.DataFrame(res_json)
@@ -740,7 +729,11 @@ class Invitation(LinkedIn):
             headers=head,
             cookies=self.cookies,
         )
-        return res.status_code != 201
+        try:
+            res.raise_for_status()
+            return "✉️ Invitation successfully sent !"
+        except requests.HTTPError as e:
+            return e
 
 
 class Message(LinkedIn):
@@ -782,6 +775,7 @@ class Message(LinkedIn):
         return df.reset_index(drop=True)
 
     def send(self, content, recipients_url=None, recipients_urn=None):
+        recipient_errors = []
         params = {"action": "create"}
         message_event = {
             "eventCreate": {
@@ -798,16 +792,19 @@ class Message(LinkedIn):
                 }
             }
         }
-        if type(recipients_url) is not list and recipients_url is not None:
+        if type(recipients_url) is str:
             recipients_url = [recipients_url]
-        if recipients_urn is not list:
-            if recipients_urn is str:
-                recipients_urn = [recipients_urn]
-            else:
-                recipients_urn = []
-        if recipients_url is not None:
+        if type(recipients_urn) is str:
+            recipients_urn = [recipients_urn]
+        if type(recipients_url) is list:
+            recipients_urn = []
             for recipient in recipients_url:
-                recipients_urn.append(self.get_profile_urn(recipient))
+                recipient_urn = LinkedIn.get_profile_urn(self, recipient)
+                if type(recipient_urn) is requests.exceptions.HTTPError:
+                    recipient_errors.append(recipient_urn)
+                recipients_urn.append(recipient_urn)
+        if len(recipient_errors) > 0:
+            return recipient_errors
         message_event["recipients"] = recipients_urn
         message_event["subtype"] = "MEMBER_TO_MEMBER"
         payload = {
@@ -821,9 +818,11 @@ class Message(LinkedIn):
             cookies=self.cookies,
             headers=self.headers,
         )
-        if res.status_code == 201:
-            print("Message successfully sent")
-        return res
+        try:
+            res.raise_for_status()
+            return "💬 Message successfully sent !"
+        except requests.HTTPError as e:
+            return e
 
 
 class Post(LinkedIn):
@@ -897,7 +896,6 @@ class Post(LinkedIn):
         if activity_id is None:
             print("Error")
             return None
-
         post = requests.get(
             f"https://www.linkedin.com/voyager/api/feed/updates/urn:li:activity:{activity_id}",
             cookies=self.cookies,
